==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/geo03.h <==
/****************************************************************************

  module      : geo03.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: logging ...
  description : description ...


  last changed: 2000-01-14  14:18
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GEO03_H
#define GEO03_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo003.h"
#include "geo40.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/
externC void 
eo03NiBuildTracefileName    (tsp00_Pathc VAR_ARRAY_REF  TracefileName) ;

externC teo00_Longuint 
eo03NiInit    (tsp00_ErrTextc VAR_ARRAY_REF  pErrTextc) ;

externC teo00_Longuint 
eo03NiConnect ( teo003_ConnectParamRecord    *pConnParam,
                teo40_NiConnectInfoRecord    *pNIConnInfo,
                tsp00_ErrTextc  VAR_ARRAY_REF ErrTextC  );

externC teo00_Longuint 
eo03NiRelease ( teo40_NiConnectInfoRecord *pNIConnInfo,
                tsp00_ErrText  VAR_ARRAY_REF  pErrText  );

externC teo00_Longuint 
eo03NiRequest  ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                 teo00_Longuint                ulCmdPacket,
                 teo00_Longuint                ulCmdDataLen,
                 tsp00_ErrText  VAR_ARRAY_REF  ErrText );

externC teo00_Longuint 
eo03NiReceive  ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                 teo003_CommPacketRecord     **ppResPacket,
                 teo00_Longuint               *pulResDataLen,
                 tsp00_ErrText VAR_ARRAY_REF   ErrText );

externC teo00_Longuint 
eo03NiSqlCancelDump       ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                            char                         *szSapRouterString,   /* PTS 1105116 */
                            teo00_Longuint                ulReqType,
                            tsp00_ErrText  VAR_ARRAY_REF  ErrText );

externC teo00_Longuint 
eo03NiSqlReplyAvailable   ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                            tsp00_ErrText  VAR_ARRAY_REF  ErrText );
/* PTS 1105295 */
externC teo00_Longuint 
eo03NiPing( char                         *szSapRouterString,
            tsp00_Versionc VAR_ARRAY_REF  szServerVersion,
            tsp00_ErrTextc VAR_ARRAY_REF  ErrTextC ) ;

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GEO03_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/geo03.h <==
/****************************************************************************

  module      : geo03.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: logging ...
  description : description ...


  last changed: 2000-01-14  14:18
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GEO03_H
#define GEO03_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "geo003.h"
#include "geo40.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/
externC void 
eo03NiBuildTracefileName    (tsp00_Pathc VAR_ARRAY_REF  TracefileName) ;

externC tsp00_Uint     
eo03NiInit    (tsp00_ErrTextc VAR_ARRAY_REF  pErrTextc) ;

externC tsp00_Uint     
eo03NiConnect ( teo003_ConnectParamRecord    *pConnParam,
                teo40_NiConnectInfoRecord    *pNIConnInfo,
                tsp00_ErrTextc  VAR_ARRAY_REF ErrTextC  );

externC tsp00_Uint     
eo03NiRelease ( teo40_NiConnectInfoRecord *pNIConnInfo,
                tsp00_ErrText  VAR_ARRAY_REF  pErrText  );

externC tsp00_Uint     
eo03NiRequest  ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                 tsp00_Uint                    ulCmdPacket,
                 tsp00_Uint                    ulCmdDataLen,
                 tsp00_ErrText  VAR_ARRAY_REF  ErrText );

externC tsp00_Uint     
eo03NiReceive  ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                 teo003_CommPacketRecord     **ppResPacket,
                 tsp00_Uint                   *pulResDataLen,
                 tsp00_ErrText VAR_ARRAY_REF   ErrText );

externC tsp00_Uint     
eo03NiSqlCancelDump       ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                            char                         *szSapRouterString,   /* PTS 1105116 */
                            tsp00_Uint                    ulReqType,
                            tsp00_ErrText  VAR_ARRAY_REF  ErrText );

externC tsp00_Uint     
eo03NiSqlReplyAvailable   ( teo40_NiConnectInfoRecord    *pNIConnInfo,
                            tsp00_ErrText  VAR_ARRAY_REF  ErrText );
/* PTS 1105295 */
externC tsp00_Uint     
eo03NiPing( char                         *szSapRouterString,
            tsp00_Versionc VAR_ARRAY_REF  szServerVersion,
            tsp00_ErrTextc VAR_ARRAY_REF  ErrTextC ) ;

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GEO03_H */
